<?php

namespace BsPayDemo;

use BsPayDemo\constants\DemoConstants;
use BsPaySdk\Online\CardPayment;
use Creditcard;
use PRCIDCard;

# 配置商户信息
require_once dirname(__FILE__) . "/loader.php";

/**
 * 线上银行卡支付模块 Demo
 */

# ------------- 快捷代扣绑卡申请 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->bind(
    DemoConstants::DEMO_HUIFU_ID,
    "MerchName",
    "10000000000",
    "20210823",
    "10000000001",
    new PRCIDCard("310103190001010983", "1", "19000101", "20251231"),   // 输入身份证相关信息
    new Creditcard("4392039291828475", "张三", "13901234567", "555", "2512")
);

echo "---> 快捷代扣绑卡申请: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}
# ---------------- END ----------------


# ------------- 快捷代扣绑卡确认 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->bindConfirm(
    DemoConstants::DEMO_HUIFU_ID,
    "MerchName",
    "10000000000",
    "20210823",
    "10000000001",
    "1234567890",
    new PRCIDCard("310103190001010983", "1", "19000101", "20251231"),   // 输入身份证相关信息
    new Creditcard("4392039291828475", "张三", "13901234567", "555", "2512"),
    "000000"
);

echo "---> 快捷代扣绑卡确认: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}
# ---------------- END ----------------


# ------------- 绑卡短信重发 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->resendBindSms(
    DemoConstants::DEMO_HUIFU_ID,
    "10000000000",
    "20210823",
    "10000000001"
);

echo "---> 绑卡短信重发: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}
# ---------------- END ----------------


# ------------- 快捷代扣解绑 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->unbind(
    DemoConstants::DEMO_HUIFU_ID,
    "Merchant_Name",
    "1000000000",
    "1234567890"
);

echo "---> 快捷代扣解绑: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}
# ---------------- END ----------------


# ------------- 快捷支付申请 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->quickPay(
    DemoConstants::DEMO_HUIFU_ID,
    "6666000103423833",
    "10.01",
    "10000067314",
    "virgo://http://www.vclinker.com"  // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
);

echo "---> 快捷支付申请: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}

# 缓存一下本次快捷支付申请情求结果，作为后续确认、查询的目标交易
$cardPaymentResult = $response -> result;
# ---------------- END ----------------


# ------------- 快捷支付确认 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->quickPayConfirm(
    DemoConstants::DEMO_HUIFU_ID,
    $cardPaymentResult["req_seq_id"],
    $cardPaymentResult["req_date"],
    "000000",
    "virgo://http://www.vclinker.com"  // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
);

echo "---> 快捷支付确认: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}

# 缓存一下本次快捷支付申请情求结果，作为后续确认、查询的目标交易
$cardPaymentConfirmResult = $response -> result;
# ---------------- END ----------------


# ------------- 银行卡交易支付退款 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->refund(
    DemoConstants::DEMO_HUIFU_ID,
    "10.01",
    $cardPaymentConfirmResult["req_date"],
    $cardPaymentConfirmResult["req_seq_id"],
    "virgo://http://www.vclinker.com"  // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
);

echo "---> 银行卡交易支付退款: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}
# ---------------- END ----------------


# ------------- 代扣支付 -------------
$cardPayment = new CardPayment();
$response = $cardPayment->deductionPay(
    DemoConstants::DEMO_HUIFU_ID,
    "6666000103423833",
    "10.01",
    "10000067314",
    "virgo://http://www.vclinker.com"  // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
);

echo "---> 代扣支付: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}
# ---------------- END ----------------