<?php
namespace BsPayDemo;

use BsPaySdk\BsPayClient;
use BsPayDemo\constants\DemoConstants;

/**
 * 统一支付通用请求方法示例
 *
 * 本示例展示了如何使用 sdk 提供的通用请求方法来实现聚合扫码接口的调用，您可以结合参考本示例与统一支付接口文档，直接快速实现其他功能或非标 api 的对接。
 * 本示例的写法直接暴露了 sdk 底层所封装的 client 对象的使用，该对象主要实现了对于统一支付接口标准的加签、验签、返回处理的基础工作，
 * 但是在传参以及字段处理方面，仍需要您通过接口文档逐一对照，按要求输入。
 *
 * 注：当然，我们仍然推荐您优先使用 sdk 所封装好的各个模块对象完成功能的调用，
 * 因为这其中还简化了不少数据加密传输、接口字段转意处理，便于您更好的理解及使用功能。
 */

# 1. 导入系统及商户参数，并完成初始化工作
require_once dirname(__FILE__) . "/loader.php";

# 2. 根据接口文档说明，创建对应请求的参数数据体
$trans_params = array(
    # 本次请求流水号，需保证当天商户下唯一，推荐采用uuid+时间戳方式避免在分布式系统中重复的可能
    "req_seq_id" => uniqid(rand(), true),
    # 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
    "req_date" => date("Ymd"),
    # 系统号，由汇付分配（系统号在完成初始化工作导入 config/congfig.json 后，请求中会默认添加，因此在这里可以不用重复设置该字段）
    "sys_id" => "SPIN",
    # 商户订单号，需保证该订单在商户系统下下唯一，可与req_seq_id相同
    "mer_ord_id" => uniqid(rand(), true),
    # 商户号
    "huifu_id" => DemoConstants::DEMO_HUIFU_ID,
    # 渠道号，若需使用自有渠道请联系业务对接人
    "bank_channel_no" => "",
    # 交易金额
    "trans_amt"=>"0.02",
    # 商品描述
    "goods_desc"=>"测试商品",
    "auth_code" => DemoConstants::WX_AUTH_CODE,
    # 设备信息，发起支付的终端设备信息，详见接口文档说明，提供本字段可以提升交易通过率，避免因数据确实而被风控
    "terminal_device_info"=>array (
        "device_type"=>"4",
        "device_ip"=>"139.207.19.246"
    ),
    # 风控信息，注意，风控信息为JSON字符串，提供本字段可以提升交易通过率，避免因数据确实而被风控
    "risk_check_info" => json_encode(array(
        "riskMngInfo" => array(
            "subTradeType" => "4300"
        ),
        "ipAddr"=>"139.207.19.246"
    )),
    # 异步通知地址，根据接口要求，通知地址必须以 "virgo://" 开始
    "notify_url" => "virgo://https://www.vclinker.com",
    # 交易有效期
    "time_expire"=>"",
    # 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
    "limit_pay"=>"1",
    # 延时标志 1为延迟 0为不延迟
    "is_delay_acct"=>"0",
    # 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
    "term_div_coupon_type"=>"3",
    # 分账串，注意只有真实分账场景才需要传入分账串，请避免传入多个分账方为同一商户的分账串
    "acct_split_bunch"=>array(
        "acct_infos" => array(
            // 分账方1
            array(
                "huifu_id"=>DemoConstants::DEMO_HUIFU_ID,
                "div_amt"=>"0.01"
            ),
            // 分账方2
            array(
                "huifu_id"=>DemoConstants::DIV_HUIFU_ID,
                "div_amt"=>"0.01"
            )
        )
    ),
    # 商户私有域
    "mer_priv"=>"",
    # 微信扩展参数集合
    "wx_data"=>"",
    # 支付宝扩展参数集合
    "alipay_data"=>"",
    # 银联扩展参数集合
    "unionpay_data"=>"",
    // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
    // 不送时取业务入驻配置的默认费率
    "pay_scene"=>"02",
);

# 3. 创建请求Client对象，调用聚合反扫接口
$trans = new BsPayClient();
$trans->postRequest("top.trans.authCodePay", $trans_params);

# 4. 处理接口返回应答
if ($trans->isError()){
    //失败处理
    var_dump($trans->result);
} else {
    //成功处理
    var_dump($trans->result);
}