<?php

namespace BsPayDemo;

use BsPayDemo\constants\DemoConstants;
use BsPaySdk\Increment\Installment;
use Bankcard;
use ReqSeqID;

# 配置商户信息
require_once dirname(__FILE__) . "/loader.php";

/**
 * 增值模块分期功能 Demo
 */

# ------------- 银行卡分期支付请求 -------------
$incrementInstallment = new Installment();
$response = $incrementInstallment->bankcardPaymentApply(
    DemoConstants::DEMO_HUIFU_ID,
    uniqid(),   //demo这里随机生成一个商户订单号
    "1.01",
    new Bankcard("张三", "6222000000001234567", "13912345678"),
    "01",
    "310110201302039827",
    "3",
    "virgo://http://www.vclinker.com"  // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
);

echo "---> 银行卡分期支付请求: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}

# 缓存一下本次分期支付请求结果，作为分期确认请求的目标交易
$applyRequestResult = $response -> result;
# --------------- END ---------------


# ------------- 银行卡分期支付确认 -------------
$incrementInstallment = new Installment();
$response = $incrementInstallment->bankcardPaymentConfirm(
    DemoConstants::DEMO_HUIFU_ID,
    uniqid(),   //demo这里随机生成一个商户订单号
    $applyRequestResult["req_seq_id"],
    $applyRequestResult["req_date"],
    "123456",
    "virgo://http://www.vclinker.com"   // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
);

echo "---> 银行卡分期支付确认: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}

# 缓存一下本次分期支付确认结果，作为后面查询的目标交易
$paymentConfirmResult = $response -> result;
# --------------- END ---------------


# ------------- 银行卡分期支付查询 -------------
$incrementInstallment = new Installment();
$response = $incrementInstallment->bankcardPaymentQuery(
    DemoConstants::DEMO_HUIFU_ID,
    $paymentConfirmResult["req_date"],
    new ReqSeqID($paymentConfirmResult["req_seq_id"])
);

echo "---> 银行卡分期支付查询: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}

# --------------- END ---------------


# ------------- 银行卡分期支付退款 -------------
$incrementInstallment = new Installment();
$response = $incrementInstallment->bankcardPaymentRefund(
    DemoConstants::DEMO_HUIFU_ID,
    uniqid(),   //demo这里随机生成一个商户订单号
    "1.01",
    new ReqSeqID($paymentConfirmResult["req_seq_id"]),
    $paymentConfirmResult["req_date"],
    "virgo://http://www.vclinker.com"   // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
);

echo "---> 银行卡分期支付退款: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}

# --------------- END ---------------


# ------------- 银行卡分期签约 -------------
$incrementInstallment = new Installment();
$response = $incrementInstallment->bankcardSignup(
    DemoConstants::DEMO_HUIFU_ID,
    "1.01",
    new Bankcard("张三", "6222000000001234567", "13912345678"),
    "01",
    "310110201302039827",
    "virgo://http://www.vclinker.com",  // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
    "http://www.baidu.com",
    "3"
);

echo "---> 银行卡分期支付请求: \n";
if ($response->isError()){  //失败处理
    var_dump($response -> result);
} else {    //成功处理
    var_dump($response -> result);
}
# --------------- END ---------------