<?php
namespace BsPaySdk\Online;

use BsPaySdk\BsPayClient;

/**
 * 线上账户余额支付模块
 *
 * @package BsPaySdk\Online
 */
class AcctPayment extends BsPayClient
{
    /**
     * 账户余额支付
     * 在不传入分账信息字段（acct_payment_split_bunch）的情况下，默认对收款客户进行全额分账
     *
     * @param string $targetHuifuId 收款客户号
     * @param string $payHuifuId 出款客户号
     * @param string $ordAmt 交易金额
     * @param array $extendInfos 可选扩展参数，详见接口文档
     *
     * @return AcctPayment 调用结果在返回对象的 result 中
     */
    public function pay($targetHuifuId,
                        $payHuifuId,
                        $ordAmt,
                        $extendInfos=array()
    ){
        $trans_params = array_merge(
            array(
                "req_seq_id" => uniqid(rand(), true),
                "req_date" => date("Ymd"),
                "huifu_id" => $targetHuifuId,
                "out_huifu_id" => $payHuifuId,
                "ord_amt" => $ordAmt,
                "acct_payment_split_bunch" => array(
                    "acct_infos" => array(
                        array(
                            "in_huifu_id" => $targetHuifuId,
                            "div_amt" => $ordAmt,
                        ),
                    ),
                ),
            ), $extendInfos);

        # 调用接口
        self::postRequest("topat.acctPayment", $trans_params);

        return $this;
    }

    /**
     * 账户余额支付查询
     *
     * @param string $huifuId 账户号
     * @param string $orgReqDate 原交易发生日期
     * @param string $orgReqSeqId 原交易流水号
     * @param array $extendInfos 可选扩展参数，详见接口文档
     *
     * @return AcctPayment 调用结果在返回对象的 result 中
     */
    public function query($huifuId,
                          $orgReqDate,
                          $orgReqSeqId,
                          $extendInfos=array()
    ){
        $trans_params = array_merge(
            array(
                "huifu_id" => $huifuId,
                "org_req_date" => $orgReqDate,
                "org_req_seq_id" => $orgReqSeqId,
            ), $extendInfos);

        # 调用接口
        self::postRequest("topat.acctPaymentQuery", $trans_params);

        return $this;
    }

    /**
     * 账户余额支付退款
     *
     * @param string $huifuId 商户号
     * @param string $ordAmt 退款金额
     * @param string $orgReqDate 原交易日期
     * @param string $orgReqSeqId 原交易流水号
     * @param array $extendInfos 可选扩展参数，详见接口文档
     *
     * @return AcctPayment 调用结果在返回对象的 result 中
     */
    public function refund($huifuId,
                           $ordAmt,
                           $orgReqDate,
                           $orgReqSeqId,
                           $extendInfos=array()
    ){
        $trans_params = array_merge(
            array(
                "req_seq_id" => uniqid(rand(), true),
                "req_date" => date("Ymd"),
                "huifu_id" => $huifuId,
                "ord_amt" => $ordAmt,
                "org_req_date" => $orgReqDate,
                "org_req_seq_id" => $orgReqSeqId,
            ), $extendInfos);

        # 调用接口
        self::postRequest("topat.acctPaymentRefund", $trans_params);

        return $this;
    }

    /**
     * 账户余额支付退款查询
     *
     * @param string $huifuId 商户号
     * @param string $orgReqDate 退款请求发生日期
     * @param string $orgReqSeqId 退款请求流水号
     * @param array $extendInfos 可选扩展参数，详见接口文档
     *
     * @return AcctPayment 调用结果在返回对象的 result 中
     */
    public function refundQuery($huifuId,
                                $orgReqDate,
                                $orgReqSeqId,
                                $extendInfos=array()
    ){
        $trans_params = array_merge(
            array(
                "req_seq_id" => $orgReqDate,
                "req_date" => $orgReqSeqId,
                "huifu_id" => $huifuId,
            ), $extendInfos);

        # 调用接口
        self::postRequest("topat.acctPaymentRefundQuery", $trans_params);

        return $this;
    }

    /**
     * 账户余额信息查询
     *
     * @param string $huifuId 账户号
     * @param array $extendInfos 可选扩展参数，详见接口文档
     *
     * @return AcctPayment 调用结果在返回对象的 result 中
     */
    public function infoQuery($huifuId,
                              $extendInfos=array()
    ){
        $trans_params = array_merge(
            array(
                "huifu_id" => $huifuId,
                "req_seq_id" => uniqid(rand(), true),
                "req_date"=> date("Ymd")
            ), $extendInfos);

        # 调用接口
        self::postRequest("topqur.acctInfoQuery", $trans_params);

        return $this;
    }

    /**
     * 账户金额冻结
     * @param array $params
     */
    public function freeze($params=array()){
        // TODO
    }

    /**
     * 账户金额解冻
     * @param array $params
     */
    public function unfreeze($params=array()){
        // TODO
    }

    /**
     * 账户资金归集
     * @param array $params
     */
    public function combine($params=array()){
        // TODO
    }
}