<?php

/**
 * Class Bankcard
 * 银行账号详细信息对象
 */
class BankAcctDetails
{
    /**
     * @var string 银行账号掩码
     */
    protected $bankAccountMask;
    /**
     * @var string 银行账号密文
     */
    protected $bankAccountCrypt;
    /**
     * @var string 银行编号
     */
    protected $bankCode;
    /**
     * @var string 银行卡用户名
     */
    protected $bankAccountName;
    /**
     * @var string 公私类型标识, 01-对公 / 02-对私
     */
    protected $publicAndPrivateFlag;
    /**
     * @var string 所属省份
     */
    protected $province;
    /**
     * @var string 所属地区
     */
    protected $area;
    /**
     * @var string 收款方三证合一码, 当为对公代发的情况下，必须要有值，否则创建对象时报错（无三合一码时，填营业执照号）
     */
    protected $threeInOneCode;

    /**
     * @throws Exception
     */
    public function __construct($bankAccountMask,
                                $bankAccountCrypt,
                                $bankCode,
                                $bankAccountName,
                                $publicAndPrivateFlag,
                                $province,
                                $area,
                                $threeInOneCode)
    {
        $this->bankAccountMask = $bankAccountMask;
        $this->bankAccountCrypt = $bankAccountCrypt;
        $this->bankCode = $bankCode;
        $this->bankAccountName = $bankAccountName;
        $this->publicAndPrivateFlag = $publicAndPrivateFlag;
        $this->province = $province;
        $this->area = $area;

        // 当为对公代发的情况下，必须要检查收款方三证合一码
        if ("01" == $publicAndPrivateFlag && !$threeInOneCode) {
            throw new Exception('对公代发必须提供收款方三证合一码');
        }
        $this->threeInOneCode = $threeInOneCode;
    }

    public function getBankAccountMask()
    {
        return $this->bankAccountMask;
    }

    public function getBankAccountCrypt()
    {
        return $this->bankAccountCrypt;
    }

    public function getBankCode()
    {
        return $this->bankCode;
    }

    public function getBankAccountName()
    {
        return $this->bankAccountName;
    }

    public function getPublicAndPrivateFlag()
    {
        return $this->publicAndPrivateFlag;
    }

    public function getProvince()
    {
        return $this->province;
    }

    public function getArea()
    {
        return $this->area;
    }

    public function getThreeInOneCode()
    {
        return $this->threeInOneCode;
    }
}