# 简介

为了提高客户接入的便捷性，本系统提供 SDK 方式介入，使用本 SDK 将极大的简化开发者的工作，开发者将无需考虑通信、签名、验签等，只需要关注业务参数的输入。

# 下载地址

[SDK下载](https://spin.cloudpnr.com/topds/sdk/phpsdk.html)

# 版本记录

| 版本 | 日期 | 版本说明 | 
| --- | --- | --- | 
| v1.0.0 | 2021/05/06 | 初始版本 |
| v1.0.1 | 2021/08/23 | 实现通用接口请求客户端演示demo，实现部分支付功能的封装 |

# 版本要求

PHP 版本 5.6 及以上

# SDK 包结构说明

**BsPaySdk** 目录下内容为待添加到项目中的文件；
**BsPayDemo** 目录下为示例项目，供接入时参考使用；

# 使用方法

1. 将 **BsPaySdk** 目录下文件内容整体复制到您的项目工程内


2. 在您的项目创建 SDK 初始化的入口文件，完成如下配置：

   2.1 进行相关环境及调试参数的配置

    ```
    # 设置是否调试模式，不配置默认关闭：false
    define("DEBUG", true);
    
    # 设置调试日志路径，不配置默认为SDK同级的log目录下
    define("LOG", dirname(__FILE__)."/log");
    
    # 设置生产模式，不配置默认生产模式：true，设置为 false 时调用联调测试环境
    define("PROD_MODE", true);
    ```

   2.2 完成 sdk 初始化

    ```
    # 加载 SDK 初始化文件
    require_once  dirname(__FILE__). "/../BsPaySdk/init.php";
    ```

   2.3 完成系统参数的导入

    ```
    # 从文件导入商户系统参数
    BsPay::init(dirname(__FILE__). '/config/config_merch_default.json', false);
    
    # sdk也支持追加多套系统参数，并可以在调用接口时进行切换，适用于下辖多商户的系统接入
    BsPay::init(dirname(__FILE__). '/config/config_merch_2.json', false, "merchantKey2");
    ```
   
   2.4 **以上内容，建议参考 SDK Demo 中 loader.php 文件内的代码写法**


3. 在业务代码中进行 SDK 的调用

   3.1 导入前一步实现的 SDK 初始化文件

   ```
   # 配置商户信息
   require_once dirname(__FILE__) . "/loader.php";
   ```

   3.2 根据接口文档说明，创建对应请求的参数数据体

   ```
   # 请求参数字典
   $trans_params = array(
       "req_seq_id" => uniqid(rand(), true),
       "req_date" => date("Ymd"),
       "sys_id" => "SPIN",
       "mer_ord_id" => uniqid(rand(), true),
       "huifu_id" => DemoConstants::DEMO_HUIFU_ID,
       "trans_amt"=>"0.02",
       "goods_desc"=>"测试商品",
       "auth_code" => DemoConstants::WX_AUTH_CODE,
       "notify_url" => "virgo://https://www.vclinker.com",
   );
   
   ```

   3.3 调用接口

   ```
   # 创建请求Client对象，调用接口
   $trans = new BsPayClient();
   $trans->postRequest("top.trans.authCodePay", $trans_params);

   ```

   3.4 处理返回结果

   ```
   # 成功/失败应答的处理
   if ($trans->isError()){
      // 失败处理
   } else {
      // 成功处理
   }
   ```

   3.5 **以上内容，建议参考 SDK Demo 中 CommonBspayClientDemo.php 文件内的代码写法**


4. 其他调用方式

   除了通用的基于 BsPayClient 来调用接口之外，SDK 还针对部分重要交易接口提供了一种更便捷的方法，
讲一些默认、非必须、无需特别关注的参数传递，以及数据脱敏、加密处理进行了封装。 使用方法如下所示：

   ```
   
   # 配置商户信息
   require_once dirname(__FILE__) . "/loader.php";
   
   # ------------- 聚合反扫支付 -------------
   
   # 创建扫码支付模块对象
   $scanPayment = new ScanPayment();
   
   # 调用模块对象下对应的功能方法获取返回结果
   $response = $scanPayment->passiveScanPay(
      DemoConstants::DEMO_HUIFU_ID,
      "0.01",
      uniqid(),   // demo这里随机生成一个商户订单号
      DemoConstants::WX_AUTH_CODE,    //这里需要生成一个真实的反扫二维码字符串才能支付成功
      "iphone12贴膜",
      array(  //可选参数
         "notify_url"=>"virgo://http://www.vclinker.com" // 该笔交易的异步通知地址（http/https异步通知地址，必须以virgo://开头）
      )
   );
   
   # 处理 成功/失败 结果
   if ($response->isError()){  
      # 失败处理
   } else {
      # 成功处理
   }
   
   # --------------- END ---------------
   ```

   模块功能表如下：

   | 功能模块 | 类对象 | Demo 示例文件 |
   | --- | --- | --- | 
   | 线上扫码支付模块 | Online\ScanPayment.php | ScanPaymentDemo.php | 
   | 线上银行卡支付模块 | Online\CardPayment.php | CardPaymentDemo.php |
   | 线上账户余额支付模块 | Online\AcctPayment.php | AcctPaymentDemo.php |
   | 取现与结算模块 | Settlement\Cashout.php | CashoutDemo.php |
   | 增值汇分期功能模块 | Increment\Installment.php | IncrementInstallmentDemo.php |
